@@ -7,7 +7,7 @@ from cherrypy.lib import xmlrpcutil
 _xmlrpclib = xmlrpcutil.get_xmlrpclib ()
 
 
-from . import base, client, tickets, security, tools, naming, plugins
+from . import base, client, tickets, security, tools, naming, plugins, async
 from base import Service
 from interfaces import CryptoInterface, MetaInterface, Namespace
 
