@@ -32,7 +32,7 @@ class EncryptedXmlrpcTool (cherrypy.Tool):
         request.rco_security = request.app.service.security_manager
 
         path = request.path_info.strip ('/')
-        request.rco_client = path [path.rfind ('/') + 1:].upper ()
+        request.rco_client = path [path.rfind ('/') + 1:].upper ().strip ()
         if not request.rco_security.public_key_exists (request.rco_client):
             raise errors.SecurityError ('Unknown client key', -1001)
 
